@@ -7,8 +7,9 @@ use File::stat;
 use File::Spec ();
 use IO::File ();
 use MIME::Types ();
+use MRO::Compat;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 __PACKAGE__->mk_accessors( qw/_static_file _static_debug_message/ );
 
@@ -49,7 +50,7 @@ sub prepare_action {
         $c->_locate_static_file( $path );
     }
     
-    return $c->NEXT::ACTUAL::prepare_action(@_);
+    return $c->next::method(@_);
 }
 
 sub dispatch {
@@ -64,7 +65,7 @@ sub dispatch {
         return $c->_serve_static;
     }
     else {
-        return $c->NEXT::ACTUAL::dispatch(@_);
+        return $c->next::method(@_);
     }
 }
 
@@ -76,13 +77,13 @@ sub finalize {
         $c->log->debug( 'Static::Simple: ' . join q{ }, @{$c->_debug_msg} );
     }
     
-    return $c->NEXT::ACTUAL::finalize(@_);
+    return $c->next::method(@_);
 }
 
 sub setup {
     my $c = shift;
     
-    $c->NEXT::setup(@_);
+    $c->maybe::next::method(@_);
     
     if ( Catalyst->VERSION le '5.33' ) {
         require File::Slurp;
@@ -278,7 +279,7 @@ Catalyst::Plugin::Static::Simple - Make serving static pages painless.
     # things or bypass Catalyst entirely in a production environment
     #
     # one caveat: the files must be served from an absolute path
-    # (ie. /images/foo.png)
+    # (i.e. /images/foo.png)
 
 =head1 DESCRIPTION
 
@@ -440,13 +441,14 @@ is automatically enabled when running Catalyst in -Debug mode.
     
 =head1 USING WITH APACHE
 
-While Static::Simple will work just fine serving files through Catalyst in
-mod_perl, for increased performance, you may wish to have Apache handle the
-serving of your static files.  To do this, simply use a dedicated directory
-for your static files and configure an Apache Location block for that
-directory.  This approach is recommended for production installations.
+While Static::Simple will work just fine serving files through Catalyst
+in mod_perl, for increased performance you may wish to have Apache
+handle the serving of your static files directly. To do this, simply use
+a dedicated directory for your static files and configure an Apache
+Location block for that directory  This approach is recommended for
+production installations.
 
-    <Location /static>
+    <Location /myapp/static>
         SetHandler default-handler
     </Location>
 
@@ -455,6 +457,29 @@ through Catalyst. You can leave Static::Simple as part of your
 application, and it will continue to function on a development server,
 or using Catalyst's built-in server.
 
+In practice, your Catalyst application is probably (i.e. should be)
+structured in the recommended way (i.e., that generated by bootstrapping
+the application with the C<catalyst.pl> script, with a main directory
+under which is a C<lib/> directory for module files and a C<root/>
+directory for templates and static files). Thus, unless you break up
+this structure when deploying your app by moving the static files to a
+different location in your filesystem, you will need to use an Alias
+directive in Apache to point to the right place. You will then need to
+add a Directory block to give permission for Apache to serve these
+files. The final configuration will look something like this:
+
+    Alias /myapp/static /filesystem/path/to/MyApp/root/static
+    <Directory /filesystem/path/to/MyApp/root/static>
+        allow from all
+    </Directory>
+    <Location /myapp/static>
+        SetHandler default-handler
+    </Location>
+
+If you are running in a VirtualHost, you can just set the DocumentRoot
+location to the location of your root directory; see 
+L<Catalyst::Engine::Apache2::MP20>.
+
 =head1 PUBLIC METHODS
 
 =head2 serve_static_file $file_path
